@@ -6,11 +6,12 @@ from datomizer.utils.constants import MANAGEMENT_PUT_TRAIN_FLOW, MANAGEMENT_GET_
 from datomizer.utils.general import ID, TRAIN_ITERATIONS
 
 
-def create_train_request() -> dict:
-    return {"sampleInputRatio": 1, "sampleOutputRatio": 1}
+def create_train_request(epochs_gan=500, epochs_vae=300) -> dict:
+    return {"sampleInputRatio": 1, "sampleOutputRatio": 1,
+            "epochsGenerativeModel": epochs_gan, "epochsFeatureReduction": epochs_vae}
 
 
-def train(dato_mapper: DatoMapper) -> int:
+def train(dato_mapper: DatoMapper, epochs_gan=500, epochs_vae=300) -> int:
     dato_mapper.wait()
     response_json = dato_mapper.datomizer.get_response_json(requests.put,
                                                             url=MANAGEMENT_PUT_TRAIN_FLOW,
@@ -18,7 +19,8 @@ def train(dato_mapper: DatoMapper) -> int:
                                                                         dato_mapper.project_id,
                                                                         dato_mapper.flow_id],
                                                             headers={"Content-Type": "application/json"},
-                                                            data=json.dumps(create_train_request()))
+                                                            data=json.dumps(create_train_request(epochs_gan,
+                                                                                                 epochs_vae)))
     return response_json
 
 
