@@ -1,4 +1,6 @@
 from datomizer.protos.autodiscoveryservice_pb2 import SchemaDiscoveryDTO, TableDTO, ColumnDTO
+from datomizer.utils.exceptions import ColumnNotFound
+from datomizer.utils.messages import COLUMN_NOT_EXISTS
 
 
 class SchemaWrapper(object):
@@ -10,7 +12,7 @@ class SchemaWrapper(object):
     def tables(self) -> list:
         return self.schema.tables
 
-    def table(self, table_name) -> TableDTO:
+    def table(self, table_name=None) -> TableDTO:
         tables = self.tables()
         table: TableDTO
         for table in tables:
@@ -19,7 +21,7 @@ class SchemaWrapper(object):
 
         return tables[0]
 
-    def columns(self, table_name) -> list:
+    def columns(self, table_name=None) -> list:
         return self.table(table_name).columns
 
     def column(self, table_name, column_name) -> ColumnDTO:
@@ -29,7 +31,7 @@ class SchemaWrapper(object):
             if column_name == column.name:
                 return column
 
-        return columns[0]
+        raise ColumnNotFound(COLUMN_NOT_EXISTS)
 
     def __str__(self):
         return str(self.schema)
