@@ -1,5 +1,7 @@
 # Data Size Limits
 MAX_COLUMN_COUNT = 1000
 MIN_ROW_COUNT = 50
-MAX_FILE_SIZE_IN_MB = 20
-MB = 2 ** 20
\ No newline at end of file
+MAX_FILE_SIZE_MB = 100
+MIN_RATIO = 0.001
+MAX_RATIO = 20
+MB = 2 ** 20
